@@ -1,7 +1,15 @@
 import json
+import os
 
-from fixtures import EnvironmentVariableFixture
-from testtools import TestCase
+from fixtures import (
+    EnvironmentVariableFixture,
+    MonkeyPatch,
+    TempDir,
+    )
+from testtools import (
+    skipUnless,
+    TestCase,
+    )
 
 from ..info_elements import (
     BuildDepends,
@@ -146,6 +154,7 @@ class ExtraFilesFromPathsTestCase(TestCase):
 
 class DistributionTestCase(TestCase):
 
+    @skipUnless(os.path.isfile('/etc/lsb-release'), "No current distro")
     def test_defaults_to_current_distro(self):
         with open('/etc/lsb-release') as fp:
             release_keys = dict(
@@ -153,6 +162,15 @@ class DistributionTestCase(TestCase):
         self.assertEqual(
             Distribution.get_default(), release_keys['DISTRIB_CODENAME'])
 
+    def test_nonexistent_lsb_release(self):
+        tmp_path = self.useFixture(TempDir()).path
+        nonexistent = os.path.join(tmp_path, 'nonexistent')
+        patch = MonkeyPatch(
+            'pkgme.info_elements.Distribution.LSB_RELEASE', nonexistent)
+        with patch:
+            default_distro = Distribution.get_default()
+        self.assertEqual('UNRELEASED', default_distro)
+
 
 class DebianFormattedTextTests(TestCase):
 
